==> hubzero-cms-2.1.0_2.1.14.10-1+deb8.tar.gz: source/cms/core/components/com_resources/site/views/emails/tmpl/submitted_plain.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access.
defined('_HZEXEC_') or die();

$db = \App::get('db');

$creator = User::getInstance($this->resource->created_by);

$type = new \Components\Resources\Tables\Type($db);
$type->load($this->resource->type);

$link = rtrim(Request::base(), '/') . '/' . ltrim(Route::url('index.php?option=com_resources&id=' . $this->resource->id), '/');

$message  = Lang::txt('COM_RESOURCES_NEW_SUBMISSION') . "\n";
$message .= '----------------------------' . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_ID')) . ' #' . $this->resource->id . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_TYPE')) . ': ' . $type->type . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_CREATED')) . ': ' . $this->resource->created . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_CREATOR')) . ': ' . $creator->get('name') . "\n";
$message .= '----------------------------' . "\n\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_TITLE')) . ': ' . $this->resource->title . "\n\n";
$message .= $this->resource->introtext . "\n\n";
$message .= 'To view the submission and take actions, go to: ' . "\n";
$message .= $link . "\n";

echo $message;

==> hubzero-cms-2.2.0_2.2.6.0-1+deb8.tar.gz: source/cms/core/components/com_resources/site/views/emails/tmpl/submitted_plain.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access.
defined('_HZEXEC_') or die();

$creator = User::getInstance($this->resource->created_by);

$type = $this->resource->type;

$link = rtrim(Request::base(), '/') . '/' . ltrim(Route::url($this->resource->link()), '/');

$message  = Lang::txt('COM_RESOURCES_NEW_SUBMISSION') . "\n";
$message .= '----------------------------' . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_ID')) . ' #' . $this->resource->id . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_TYPE')) . ': ' . $type->type . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_CREATED')) . ': ' . $this->resource->created . "\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_CREATOR')) . ': ' . $creator->get('name') . "\n";
$message .= '----------------------------' . "\n\n";
$message .= strtoupper(Lang::txt('COM_RESOURCES_TITLE')) . ': ' . $this->resource->title . "\n\n";
$message .= $this->resource->introtext . "\n\n";
$message .= 'To view the submission and take actions, go to: ' . "\n";
$message .= $link . "\n";

echo $message;
